@@ -6,18 +6,26 @@ knitr::opts_chunk$set(message = TRUE,
 
 ## ----libs, eval = TRUE, include = FALSE----------------------------------
 library(spatsoc); library(data.table)
-DT <- fread(system.file("extdata", "DT.csv", package = "spatsoc"))
+DT <- fread(system.file("extdata", "DT.csv", package = "spatsoc"))[ID %in% c('H', 'I', 'J')]
 DT[, datetime := as.POSIXct(datetime, tz = 'UTC')]
 
 ## ---- echo = TRUE--------------------------------------------------------
+#  ## Load packages
 #  library(spatsoc)
 #  library(data.table)
+#  
+#  ## Read in spatsoc's example data
 #  DT <- fread(system.file("extdata", "DT.csv", package = "spatsoc"))
+#  
+#  ## Subset to only individuals H, I, and J
+#  DT <- DT[ID %in% c('H', 'I', 'J')]
+#  
+#  ## Cast character column 'datetime' as POSIXct
 #  DT[, datetime := as.POSIXct(datetime,
 #                              tz = 'UTC')]
 
 ## ---- eval = TRUE--------------------------------------------------------
-knitr::kable(DT[sample(.N, 5)])
+knitr::kable(DT[, .SD[1:2], ID][order(datetime)])
 
 ## ----groupmins, echo = TRUE----------------------------------------------
 #  group_times(DT, datetime = 'datetime', threshold = '5 minutes')
@@ -52,16 +60,19 @@ knitr::kable(
 
 ## ----grouppts, echo = TRUE-----------------------------------------------
 #  group_times(DT = DT, datetime = 'datetime', threshold = '15 minutes')
-#  group_pts(DT, threshold = 50, id = 'ID', coords = c('X', 'Y'))
+#  group_pts(DT, threshold = 50, id = 'ID', coords = c('X', 'Y'), timegroup = 'timegroup')
 
 ## ----fakegrouppts, eval = TRUE-------------------------------------------
-knitr::kable(
-  group_pts(
-    DT = group_times(DT = DT, datetime = 'datetime', 
-                     threshold = '15 minutes'),
+DT <- group_times(DT = DT, datetime = 'datetime', 
+                     threshold = '15 minutes')
+DT <- group_pts(
+    DT = DT,
     threshold = 50, id = 'ID', coords = c('X', 'Y'),
-    timegroup = 'timegroup')[
-      order(group)][
+    timegroup = 'timegroup')
+
+knitr::kable(
+  DT[
+      between(group,  771, 774)][order(timegroup)][
         1:nRows, .(ID, X, Y, timegroup, group)]
 )
 
@@ -74,14 +85,15 @@ knitr::kable(
 
 ## ----grouplines, eval = TRUE---------------------------------------------
 utm <- '+proj=utm +zone=21 ellps=WGS84'
+
+DT <- group_times(DT = DT, datetime = 'datetime', 
+                threshold = '1 day')
+DT <- group_lines(DT,
+                  threshold = 50, projection = utm, 
+                  id = 'ID', coords = c('X', 'Y'), 
+                  sortBy = 'datetime', timegroup = 'timegroup')
 knitr::kable(
-  group_lines(
-    group_times(DT = DT, datetime = 'datetime', 
-                threshold = '1 day'), 
-    threshold = 50, projection = utm, 
-    id = 'ID', coords = c('X', 'Y'), sortBy = 'datetime'
-  )[order(group)][
-        1:nRows, .(ID, X, Y, timegroup, group)]
+  unique(DT[, .(ID, timegroup, group)])[, .SD[1:3], ID][order(timegroup)]
 )
 
 ## ----fakegrouppolys, echo = TRUE-----------------------------------------
